import logging

log = logging.getLogger('paranoia')


def report(signal, message=None, flag=None, sender=None, values=None,
           request_path=None, request_meta=None, **kwargs):
    log.warning(message)



from .signals import finished


class Middleware(object):

    def process_response(self, request, response):
        finished.send(sender=self, request_path=request.build_absolute_uri(),
                      request_meta=request.META.copy())
        return response
